--
-- Ideal Biquad section to realize an IIR filter
-- Used by simulations
--

entity ideal_biquad is
   port (x : in real;
         y : out real;
         a1: in real;
         a2: in real;
         b1: in real;
         b2: in real);
end entity ideal_biquad;

--
-- Implementation
--
architecture behaviour of ideal_biquad is
   signal h1 : real := 0.0;   -- history value
   signal h2 : real := 0.0;
begin
   -- compute second-order section
   sos: process (x) is
      variable h0 : real;
   begin
   -- apply single second order section
   h0 := x - h1 * a1 - h2 * a2;
   y  <= h0 + h1 * b1 + h2 * b2;
   -- update history buffers
   h2 <= h1;
   h1 <= h0;
   end process sos;
end architecture behaviour;

